@@ -1,10 +1,10 @@
 # Mobile Verification Toolkit (MVT)
-# Copyright (c) 2021-2022 Claudio Guarnieri.
+# Copyright (c) 2021-2023 Claudio Guarnieri.
 # Use of this software is governed by the MVT License 1.1 that can be found at
 #   https://license.mvt.re/1.1/
 
 import logging
-from typing import Optional
+from typing import Optional, List, Dict, Union, Any
 
 from mvt.android.modules.adb.dumpsys_receivers import (
     INTENT_DATA_SMS_RECEIVED, INTENT_NEW_OUTGOING_CALL,
@@ -24,7 +24,7 @@ class DumpsysReceivers(AndroidQFModule):
         results_path: Optional[str] = None,
         fast_mode: Optional[bool] = False,
         log: logging.Logger = logging.getLogger(__name__),
-        results: Optional[list] = None
+        results: Union[List[Any], Dict[str, Any], None] = None
     ) -> None:
         super().__init__(file_path=file_path, target_path=target_path,
                          results_path=results_path, fast_mode=fast_mode,
