@@ -1,5 +1,5 @@
 # Mobile Verification Toolkit (MVT)
-# Copyright (c) 2021-2022 Claudio Guarnieri.
+# Copyright (c) 2021-2023 Claudio Guarnieri.
 # Use of this software is governed by the MVT License 1.1 that can be found at
 #   https://license.mvt.re/1.1/
 
@@ -7,7 +7,7 @@ import csv
 import logging
 import os
 import re
-from typing import Callable, Optional, Union
+from typing import Callable, Optional, Union, List, Any, Dict
 
 import simplejson as json
 
@@ -37,7 +37,7 @@ class MVTModule:
         results_path: Optional[str] = None,
         fast_mode: Optional[bool] = False,
         log: logging.Logger = logging.getLogger(__name__),
-        results: Optional[list] = None
+        results: Union[List[Dict[str, Any]], Dict[str, Any], None] = None
     ) -> None:
         """Initialize module.
 
